% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sRDA-package.r, R/sRDA.R
\docType{package}
\name{sRDA}
\alias{sRDA}
\alias{sRDA-package}
\title{sRDA.}
\usage{
sRDA(predictor, predicted, penalization = "enet", ridge_penalty = 1,
  nonzero = 1, max_iterations = 100, tolerance = 1 * 10^-25,
  cross_validate = FALSE, parallel_CV = TRUE, nr_subsets = 10,
  multiple_LV = FALSE, nr_LVs = 1)
}
\arguments{
\item{predictor}{The n*p matrix of the predictor data set}

\item{predicted}{The n*q matrix of the predicted data set}

\item{penalization}{The penalization method applied during the analysis (none, enet or ust)}

\item{ridge_penalty}{The ridge penalty parameter of the predictor set's latent variable used 
for enet or ust (an integer if cross_validate = FALE, a list otherwise)}

\item{nonzero}{The number of non-zero weights of the predictor set's latent variable 
(an integer if cross_validate = FALE, a list otherwise)}

\item{max_iterations}{The maximum number of iterations of the algorithm}

\item{tolerance}{Convergence criteria}

\item{cross_validate}{K-fold cross validation to find best optimal penalty parameters 
(TRUE or FALSE)}

\item{parallel_CV}{Run the cross validation parallel (TRUE or FALSE)}

\item{nr_subsets}{Number of subsets for k-fold cross validation}

\item{multiple_LV}{Obtain multiple latent variables (TRUE or FALSE)}

\item{nr_LVs}{Number of latent variables to be obtained}
}
\value{
An object of class \code{"srda"}.

\item{ALPHA}{
Weights of the predictor set's latent variable}

\item{BETA}{
Weights of the predicted set's latent variable}

\item{Nr_iterations}{
Number of iterations the algorithm did until convergence}

\item{XI}{
Predictor set's latent variable scores}

\item{ETA}{
Predictive set's latent variable scores}

\item{SOLVE_XIXI}{
Inverse of the predictor set's latent variable variance matrix}
}
\description{
sRDA.

Sparse Redundancy Analysis to express the maximum variance in the predicted
data set by a linear combination of variables of the predictive data set
}
\section{functions}{

functionsss
}
\examples{
\dontrun{

# generate data
dataXY <- generate_data(number_of_ksi = 1,
                           number_of_patients = 500,
                           number_of_Xs_associated_with_ksis = c(5),
                           number_of_not_associated_Xs = 250,
                           mean_of_the_regression_weights_of_the_associated_Xs =
                             c(0.9),
                           sd_of_the_regression_weights_of_the_associated_Xs =
                             c(0.05),
                           Xnoise_min = -0.3, Xnoise_max = 0.3,
                           
                           number_of_Ys_associated_with_ksis = c(5),
                           number_of_not_associated_Ys = 350,
                           mean_of_the_regression_weights_of_the_associated_Ys =
                             c(0.9),
                           sd_of_the_regression_weights_of_the_associated_Ys =
                             c(0.05),
                           Ynoise_min = -0.3, Ynoise_max = 0.3)

# seperate predictor and predicted sets
X <- dataXY$X
Y <- dataXY$Y

# run sRDA
RDA.res <- sRDA(predictor = X, predicted = Y, nonzero = 5, 
ridge_penalty = 1, penalization = "ust")

# check first 10 weights of X
RDA.res$ALPHA[1:10]

# run sRDA with cross-validation to determine best penalization parameters
RDA.res <- sRDA(predictor = X, predicted = Y, nonzero = c(5,10,15), 
ridge_penalty = c(0.1,1), penalization = "enet", cross_validate = TRUE,
parallel_CV = TRUE)

# check first 10 weights of X
RDA.res$ALPHA[1:10]
RDA.res$ridge_penalty
RDA.res$nr_nonzeros

# obtain multiple latent variables
RDA.res <- sRDA(predictor = X, predicted = Y, nonzero = c(5,10,15), 
ridge_penalty = c(0.1,1), penalization = "enet", cross_validate = TRUE, 
parallel_CV = TRUE, multiple_LV = TRUE, nr_LVs = 3, max_iterations = 5)

# check first 10 weights of X in first two component
RDA.res$ALPHA[[1]][1:10]
RDA.res$ALPHA[[2]][1:10]

# scores are orthogonal to each other
t(RDA.res$XI[[1]]) \%*\% RDA.res$XI[[2]]

}
}
\author{
Attila Csala
}
\keyword{RDA}
\keyword{Redundancy}

